@@ -23,7 +23,6 @@ from kivy.metrics import sp,dp,mm
 from kivy.core.window import WindowBase, Window
 from kivy.properties import BooleanProperty
 from kivy.uix.widget import Widget
-from kivy.clock import mainthread
 from kivy.uix.modalview import ModalView
 from kivy.app import App
 from kivy.factory import Factory
@@ -166,7 +165,6 @@ class Blocks(EventDispatcher):
 			try:
 				hc = HttpClient()
 				resp=hc(url,method=method,params=params,files=files)
-				# print('Blocks.py :resp=',resp)
 				return resp
 			except Exception as e:
 				print_exc()
@@ -734,6 +732,8 @@ class Blocks(EventDispatcher):
 					return _find_widget(name, 
 								from_widget=from_widget.parent,
 								dir=dir)
+			Logger.info('Block:_find_widget(), %s, %s %s return None',
+						name, from_widget.__class__.__name__, dir)
 			return None
 
 		def find_widget(step, from_widget):
