@@ -7,14 +7,13 @@ from kivy.uix.boxlayout import BoxLayout
 from kivy.uix.button import Button
 from kivy.clock import Clock
 from kivy.app import App
-from kivy.properties import BooleanProperty
 from functools import partial
 from appPublic.dictObject import DictObject
 from appPublic.jsonConfig import getConfig
 from .baseWidget import Text, HTTPDataHandler
 from .utils import CSize, absurl, alert
 from .form import StrSearchForm
-from .dataloader import HttpDataLoader
+from .dataloader import UrlDataLoader
 from .dataloader import ListDataLoader
 from .dataloader import RegisterFunctionDataLoader
 
@@ -41,8 +40,8 @@ it fires two type of event
 """
 
 class PageLoader(EventDispatcher):
-	loading = BooleanProperty(False)
 	def __init__(self,target=None, **options):
+		self.loading = False
 		self.target = target
 		self.options = options
 		self.filter = None
@@ -63,7 +62,7 @@ class PageLoader(EventDispatcher):
 		self.register_event_type('on_pageloaded')
 		self.newbegin = True
 		if self.url:
-			self.loader = HttpDataLoader(self)
+			self.loader = UrlDataLoader(self)
 		elif self.rfname:
 			self.loader = RegisterFunctionDataLoader(self)
 		elif self.data:
@@ -73,12 +72,6 @@ class PageLoader(EventDispatcher):
 		self.loader.bind(on_success=self.show_page)
 		self.loader.bind(on_error=self.onerror)
 	
-	def on_loading(self, *args):
-		if self.loading:
-			self.running = Running(self.target)
-		else:
-			self.running.dismiss()
-
 	def on_newbegin(self):
 		pass
 
